# Table of contents

* [Introduction](README.md)
* [Quickstart](quickstart.md)
* [Getting started](getting-started/README.md)
  * [Install Feast](getting-started/install-feast.md)
  * [Create a feature repository](getting-started/create-a-feature-repository.md)
  * [Deploy a feature store](getting-started/deploy-a-feature-store.md)
  * [Build a training dataset](getting-started/build-a-training-dataset.md)
  * [Load data into the online store](getting-started/load-data-into-the-online-store.md)
  * [Read features from the online store](getting-started/read-features-from-the-online-store.md)
* [Community](community.md)
* [Roadmap](roadmap.md)
* [Changelog](https://github.com/feast-dev/feast/blob/master/CHANGELOG.md)

## Concepts

* [Overview](concepts/overview.md)
* [Feature view](concepts/feature-view.md)
* [Data model](concepts/data-model-and-concepts.md)
* [Online store](concepts/online-store.md)
* [Offline store](concepts/offline-store.md)
* [Provider](concepts/provider.md)
* [Architecture](concepts/architecture-and-components.md)

## Reference

* [Data sources](reference/data-sources/README.md)
  * [BigQuery](reference/data-sources/bigquery.md)
  * [File](reference/data-sources/file.md)
* [Offline stores](reference/offline-stores/README.md)
  * [File](reference/offline-stores/file.md)
  * [BigQuery](reference/offline-stores/untitled.md)
* [Online stores](reference/online-stores/README.md)
  * [SQLite](reference/online-stores/sqlite.md)
  * [Redis](reference/online-stores/redis.md)
  * [Datastore](reference/online-stores/datastore.md)
* [Providers](reference/providers/README.md)
  * [Local](reference/providers/local.md)
  * [Google Cloud Platform](reference/providers/google-cloud-platform.md)
* [Feature repository](reference/feature-repository/README.md)
  * [feature\_store.yaml](reference/feature-repository/feature-store-yaml.md)
  * [.feastignore](reference/feature-repository/feast-ignore.md)
* [Feast CLI reference](reference/feast-cli-commands.md)
* [Python API reference](http://rtd.feast.dev/)
* [Usage](reference/usage.md)

## Feast on Kubernetes

* [Getting started](feast-on-kubernetes/getting-started/README.md)
  * [Install Feast](feast-on-kubernetes/getting-started/install-feast/README.md)
    * [Docker Compose](feast-on-kubernetes/getting-started/install-feast/quickstart.md)
    * [Kubernetes \(with Helm\)](feast-on-kubernetes/getting-started/install-feast/kubernetes-with-helm.md)
    * [Amazon EKS \(with Terraform\)](feast-on-kubernetes/getting-started/install-feast/kubernetes-amazon-eks-with-terraform.md)
    * [Azure AKS \(with Helm\)](feast-on-kubernetes/getting-started/install-feast/kubernetes-azure-aks-with-helm.md)
    * [Azure AKS \(with Terraform\)](feast-on-kubernetes/getting-started/install-feast/kubernetes-azure-aks-with-terraform.md)
    * [Google Cloud GKE \(with Terraform\)](feast-on-kubernetes/getting-started/install-feast/google-cloud-gke-with-terraform.md)
    * [IBM Cloud Kubernetes Service \(IKS\) and Red Hat OpenShift \(with Kustomize\)](feast-on-kubernetes/getting-started/install-feast/ibm-cloud-iks-with-kustomize.md)
  * [Connect to Feast](feast-on-kubernetes/getting-started/connect-to-feast/README.md)
    * [Python SDK](feast-on-kubernetes/getting-started/connect-to-feast/python-sdk.md)
    * [Feast CLI](feast-on-kubernetes/getting-started/connect-to-feast/feast-cli.md)
  * [Learn Feast](feast-on-kubernetes/getting-started/learn-feast.md)
* [Concepts](feast-on-kubernetes/concepts/README.md)
  * [Overview](feast-on-kubernetes/concepts/overview.md)
  * [Architecture](feast-on-kubernetes/concepts/architecture.md)
  * [Entities](feast-on-kubernetes/concepts/entities.md)
  * [Sources](feast-on-kubernetes/concepts/sources.md)
  * [Feature Tables](feast-on-kubernetes/concepts/feature-tables.md)
  * [Stores](feast-on-kubernetes/concepts/stores.md)
* [Tutorials](feast-on-kubernetes/tutorials-1/README.md)
  * [Minimal Ride Hailing Example](https://github.com/feast-dev/feast/blob/master/examples/minimal/minimal_ride_hailing.ipynb)
* [User guide](feast-on-kubernetes/user-guide/README.md)
  * [Overview](feast-on-kubernetes/user-guide/overview.md)
  * [Getting online features](feast-on-kubernetes/user-guide/getting-online-features.md)
  * [Getting training features](feast-on-kubernetes/user-guide/getting-training-features.md)
  * [Define and ingest features](feast-on-kubernetes/user-guide/define-and-ingest-features.md)
  * [Extending Feast](feast-on-kubernetes/user-guide/extending-feast.md)
* [Reference](feast-on-kubernetes/reference-1/README.md)
  * [Configuration Reference](feast-on-kubernetes/reference-1/configuration-reference.md)
  * [Feast and Spark](feast-on-kubernetes/reference-1/feast-and-spark.md)
  * [Metrics Reference](feast-on-kubernetes/reference-1/metrics-reference.md)
  * [Limitations](feast-on-kubernetes/reference-1/limitations.md)
  * [API Reference](feast-on-kubernetes/reference-1/api/README.md)
    * [Go SDK](https://godoc.org/github.com/feast-dev/feast/sdk/go)
    * [Java SDK](https://javadoc.io/doc/dev.feast/feast-sdk)
    * [Core gRPC API](https://api.docs.feast.dev/grpc/feast/core/coreservice.pb.html)
    * [Python SDK](https://api.docs.feast.dev/python/)
    * [Serving gRPC API](https://api.docs.feast.dev/grpc/feast/serving/servingservice.pb.html)
    * [gRPC Types](https://api.docs.feast.dev/grpc/feast/types/value.pb)
* [Advanced](feast-on-kubernetes/advanced-1/README.md)
  * [Troubleshooting](feast-on-kubernetes/advanced-1/troubleshooting.md)
  * [Metrics](feast-on-kubernetes/advanced-1/metrics.md)
  * [Audit Logging](feast-on-kubernetes/advanced-1/audit-logging.md)
  * [Security](feast-on-kubernetes/advanced-1/security.md)
  * [Upgrading Feast](feast-on-kubernetes/advanced-1/upgrading.md)

## Contributing

* [Contribution process](contributing/contributing.md)
* [Development guide](contributing/development-guide.md)
* [Versioning policy](contributing/versioning-policy.md)
* [Release process](contributing/release-process.md)

